@@ -1,6 +1,8 @@
 import json
 
 from pydantic import AnyUrl, BaseModel
+from pydantic.json import pydantic_encoder
+
 
 class Base(BaseModel):
 
@@ -10,7 +12,7 @@ class Base(BaseModel):
         copy_on_model_validation = False
         smart_union = True
         # Allow us to use the field name like service.id rather than service.@id
-        allow_population_by_field_name = True 
+        allow_population_by_field_name = True
 
     def __getattribute__(self, prop):
         val = super(Base, self).__getattribute__(prop)
@@ -59,7 +61,7 @@ class Base(BaseModel):
 
         json_kwargs = dict([(arg, kwargs[arg]) for arg in kwargs.keys() if arg not in pydantic_args + excluded_args])
         return json.dumps({"@context": "http://iiif.io/api/presentation/3/context.json",
-                           **self.dict(exclude_unset=False, exclude_defaults=False, exclude_none=True, by_alias=True, **dict_kwargs)}, **json_kwargs)
+                           **self.dict(exclude_unset=False, exclude_defaults=False, exclude_none=True, by_alias=True, **dict_kwargs)}, default=pydantic_encoder, **json_kwargs)
 
     def jsonld_dict(self, **kwargs):
         pydantic_args = ["include", "exclude", "encoder"]
