@@ -5,7 +5,7 @@ from .add_range import AddRange  # noqa: F401
 from .add_service import AddService  # noqa: F401
 from .annotation_helpers import AnnotationHelpers  # noqa: F401
 from .auto_fields import *  # noqa: F401,F403
-from .canvas_helpers import AddImageToCanvas  # noqa: F401
+from .canvas_helpers import CanvasHelpers  # noqa: F401
 from .canvas_sizes import MaxHelper, MinHelper  # noqa: F401
 from .create_canvas_from_iiif import CreateCanvasFromIIIF  # noqa: F401
 from .make_canvas import MakeCanvas  # noqa: F401
