@@ -10,10 +10,8 @@ class AddLabel:
         """Adds a label to an existing resource.
 
         Args:
-            value (str or list): The label or labels to be added
-            language (str): An optional language for the labels. If not provided
-                it will default using the AutoLang configuration.
-
+            value (Union[str, list]): The label or labels to be added
+            language (str): An optional language for the labels. If not provided it will default using the AutoLang configuration.
         """
         if not self.label:
             if not language:
