@@ -5,20 +5,25 @@ from ..skeleton import (Annotation, AnnotationPage, Canvas, Collection,
 
 class AnnotationHelpers:
 
-    def add_annotation(self, annotation):
+    def add_annotation(self, annotation, anno_page_id=None):
         """Adds the annotation object to the (AnnotationPage object in the) annotations property.
 
-        Args:
-          annotation (Annotation): the Annotation to add
-
         Creates an AnnotationPage object if it doesn't exist.
+
+        Args:
+            annotation (Annotation): the Annotation to add
+            anno_page_id (str): An HTTP URL for the annotation page to which the annotation will be attached.
+
+        Returns:
+            annotation (Annotation): the Annotation attached to the AnnotationPage.
+
         """
         if not self.annotations:
             self.annotations = list()
 
         if len(self.annotations) == 0:
             # add empty AnnotationPage
-            anno_page = AnnotationPage(items=[])
+            anno_page = AnnotationPage(id=anno_page_id, items=[])
             self.annotations.append(anno_page)
         else:
             anno_page = self.annotations[0]
@@ -27,14 +32,15 @@ class AnnotationHelpers:
 
         return annotation
 
-    def make_annotation(self, **kwargs):
+    def make_annotation(self, anno_page_id=None, **kwargs):
         """Creates an annotation object and adds it to the annotations property using .add_annotation().
 
         Args:
+            anno_page_id (str): An HTTP URL for the annotation page to which the annotation will be attached.
             **kwargs (): see Annotation.
         """
         annotation = Annotation(**kwargs)
-        self.add_annotation(annotation)
+        self.add_annotation(annotation, anno_page_id=anno_page_id)
         return annotation
 
 
